@@ -23,7 +23,18 @@ cron.ci <- function(x, conf = 0.95, type = "logit", B = 1000){
     ci <- c( theta - za * sqrt(vtheta), theta + za * sqrt(vtheta) )
     ci <- exp(ci) / ( 1 + exp(ci) )
 
-  } else if ( type == "boot" ) {
+  } else if ( type == "boot" )  {
+    x2 <- cbind( Rfast::rowsums(x), x )
+    ab <- numeric(B)
+    for (i in 1:B) {
+      ind <- Rfast2::Sample.int(n, n, replace = TRUE)
+      y <- x2[ind, ]
+      s <- Rfast::colVars(y)
+      ab[i] <- 1 - sum(s[-1]) / s[1]
+    }
+    ci <- p / (p - 1) * quantile( ab, probs = c(0.025, 0.975) )
+
+  } else if ( type == "bca.boot" ) {
 
     aboot <- function(x, i) {
       s <- cov(x[i, ])
@@ -35,6 +46,21 @@ cron.ci <- function(x, conf = 0.95, type = "logit", B = 1000){
     ci <- boot::boot.ci(b, type = "bca")$bca[4:5]
   }
 
+  else if ( type == "cheap.boot" ) {
+    x2 <- cbind( Rfast::rowsums(x), x )
+    ab <- numeric(B)
+    for ( i in 1:B ) {
+      ind <- Rfast2::Sample.int(n, n, replace = TRUE)
+      y <- x2[ind, ]
+      s <- Rfast::colVars(y)
+      ab[i] <- 1 - sum(s[-1]) / s[1]
+    }
+    ab <- p / (p - 1) * ab
+    s2 <- sum( (ab - a)^2 ) / B
+    ta <- qt( conf + 0.5 * (1 - conf), B )
+    ci <- c(a - ta * sqrt(s2), a + ta * sqrt(s2) )
+  }
+
   names(ci) <- c( paste( 0.5 * (1 - conf), "%", sep = "" ),
                   paste( conf + 0.5 * (1 - conf), "%", sep = "" ) )
   ci
